@@ -1,8 +1,6 @@
 from typing import Dict
-import workspace.deps
+from workspace import deps, message, git
 import os
-import workspace.message
-import workspace.git
 from colorama import Fore, Back, Style
 
 def generate():
@@ -12,6 +10,14 @@ def generate():
   cmake = "cmake_minimum_required(VERSION 3.0)\n"
   cmake += "project(workspace)\n\n"
 
+  cmake += """
+add_compile_options(
+  $<$<CXX_COMPILER_ID:GNU>:-fdiagnostics-color=always>
+  $<$<CXX_COMPILER_ID:Clang>:-fcolor-diagnostics>
+)
+
+"""
+
   for directory in git.get_directories():
     cmakes = ['']
     
