@@ -38,7 +38,7 @@ def install(repository_name):
     vendor_dir = os.path.dirname(repository['directory'])
 
     if not os.path.exists(vendor_dir):
-      os.mkdir(vendor_dir)
+      os.makedirs(vendor_dir)
     
     branch = ''
     if repository['branch']:
